Name:          qoauth
Summary:       Qt-based C++ library for OAuth authorization scheme
Group:         Graphical desktop/KDE
Version:       2.0.1
Release:       %mkrel 2
License:       LGPLv2+
URL:           http://github.com/ayoy/qoauth
# tarball 2.0.1 come from: https://github.com/ayoy/qoauth/commit/02fbc13a42d945b703a28a49d71c02b20c76a0b8
Source0:       http://files.ayoy.net/qoauth/release/%{version}/src/%{name}-%{version}-src.tar.gz
Patch0:        qoauth-2.0.1-Qt5-port.patch
BuildRequires: qt4-devel
BuildRequires: qca2-devel
BuildRequires: doxygen

BuildRequires: pkgconfig(Qt5Core)
BuildRequires: pkgconfig(Qt5Network)
BuildRequires: pkgconfig(Qt5Test)
BuildRequires: pkgconfig(qca2-qt5)

%description 
QOAuth is an attempt to support interaction with OAuth-powered network 
services in a Qt way, i.e. simply, clearly and efficiently. It gives 
the application developer no more than 4 methods, namely:

* requestToken() to obtain an unauthorized Request Token,
* accessToken() to exchange Request Token for the Access Token,
* createParametersString() to construct a request according to OAuth
  authorization scheme,
* inlineParemeters() - to construct a query string basing on given 
  parameters (provided only for convenience).

#-----------------------------------------------------------------------------   
%define qoauth_major 1
%define libqoauth %mklibname qoauth %{qoauth_major}

%package -n    %{libqoauth}
Summary:       %{name} Qt4 core library
Group:         System/Libraries
Requires:      qca2-plugin-openssl

%description -n %{libqoauth}
%{name} Qt4 core library.

%files -n %{libqoauth}
%{_qt4_libdir}/libqoauth.so.%{qoauth_major}{,.*}

#-----------------------------------------------------------------------------

%define develname %mklibname qoauth -d

%package -n    %{develname}
Summary:       Qt4 Devel stuff for %{name}
Group:         Development/KDE and Qt
Requires:      %{libqoauth} = %{version}-%{release}
Provides:      qoauth-devel = %{version}-%{release}
Provides:      libqoauth-devel = %{version}-%{release}
Obsoletes:     qoauth-devel < 1.0.1-4

%description -n %{develname}
This package contains Qt4 header files needed if you wish to build
applications based on %{name}.

%files -n %{develname}
%doc qt4/doc/html qt4/doc/examples
%{_qt4_includedir}/QtOAuth
%{_qt4_libdir}/libqoauth.prl
%{_qt4_libdir}/libqoauth.so
%{_qt4_libdir}/pkgconfig/qoauth.pc
%{qt4dir}/mkspecs/features/oauth.prf

#----------------------------------------------------------------------------- 
### Qt5 ###

%define qoauth_qt5_major 2
%define libqoauth_qt5 %mklibname qoauth 5 %{qoauth_qt5_major}

%package -n    %{libqoauth_qt5}
Summary:       %{name} Qt5 core library
Group:         System/Libraries
Requires:      qca-qt5

%description -n %{libqoauth_qt5}
%{name} Qt5 core library.

%files -n %{libqoauth_qt5}
%{_qt5_libdir}/libqoauth5.so.%{qoauth_qt5_major}{,.*}

#-----------------------------------------------------------------------------

%define develname_qt5 %mklibname qoauth-qt5 -d

%package -n    %{develname_qt5}
Summary:       Qt5 Devel stuff for %{name}
Group:         Development/KDE and Qt
Requires:      %{libqoauth_qt5} = %{version}-%{release}
Provides:      qoauth-qt5-devel = %{version}-%{release}
Provides:      libqoauth-qt5-devel = %{version}-%{release}

%description -n %{develname_qt5}
This package contains Qt5 header files needed if you wish to build
applications based on %{name}.

%files -n %{develname_qt5}
%doc qt5/doc/html qt5/doc/examples
%{_qt5_includedir}/QtOAuth/
%{_qt5_libdir}/libqoauth5.prl
%{_qt5_libdir}/libqoauth5.so
%{_qt5_libdir}/pkgconfig/qoauth-qt5.pc
%{_qt5_prefix}/mkspecs/features/oauth.prf

### End Qt5 ###
#-----------------------------------------------------------------------------

%prep
%setup -q -c
mv %{name}-%{version}-src qt4
cp -a qt4 qt5

### Prepare Qt4 ###
pushd qt4
sed -i -e 's\/lib\/%{_lib}\g' src/pcfile.sh
popd
### Prepare Qt5 ###
pushd qt5
%patch0 -p1
sed -i -e 's\/lib\/%{_lib}\g' src/pcfile.sh
popd

%build
### Qt4 build ###
pushd qt4
%qmake_qt4
%make_build

doxygen Doxyfile
popd

### Qt5 build ###
pushd qt5
%qmake_qt5
%make_build

doxygen Doxyfile
popd

%install
%make_install -C qt4 INSTALL_ROOT=%{buildroot}
%make_install -C qt5 INSTALL_ROOT=%{buildroot}

# fix the time stamp
pushd qt4
for file in doc/html/*; do
     touch -r Doxyfile $file
done
popd

pushd qt5
for file in doc/html/*; do
     touch -r Doxyfile $file
done
popd

%check
pushd qt4
make check || :
popd

pushd qt5
make check || :
popd


%changelog
* Wed Jun 15 2016 daviddavid <daviddavid> 2.0.1-2.mga6
+ Revision: 1021511
- fix QtOAuth includedir path in oauth.prf file from Qt5 (fixes mga#18711)

* Sun May 22 2016 daviddavid <daviddavid> 2.0.1-1.mga6
+ Revision: 1017468
- new version: 2.0.1
- add Qt5 support (needed now for choqok port to KF5)

* Wed Feb 03 2016 umeabot <umeabot> 1.0.1-9.mga6
+ Revision: 933605
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.0.1-8.mga5
+ Revision: 739417
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.1-7.mga5
+ Revision: 688501
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.0.1-6.mga4
+ Revision: 517872
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.0.1-5.mga3
+ Revision: 379862
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jun 27 2011 ahmad <ahmad> 1.0.1-4.mga2
+ Revision: 114927
- libify the devel package (and add some more provides)
- Correct the License tag
- Move the doxygen building to %%build

* Wed Feb 16 2011 mikala <mikala> 1.0.1-3.mga1
+ Revision: 52105
- Remove BuildRoot
- imported package qoauth


* Fri Jan 28 2011 Sergio Rafael Lemke <sergio@mandriva.com> 1.0.1-3mdv2011.0
+ Revision: 633706
- bump release to make choqok and other buildable

* Fri Aug 20 2010 Funda Wang <fwang@mandriva.org> 1.0.1-2mdv2011.0
+ Revision: 571482
- move requires into lib package as there is no main package generated.
- correct url and license
- use standard prefix as qt has nothing to do with kde's prefix

* Sat Aug 14 2010 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.1-1mdv2011.0
+ Revision: 569811
- Fix file list
- import qoauth


